/*
 * Copyright (c) 2002, 2003 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_CATEGORY_API_H
#define _ST_CATEGORY_API_H

#include <glib.h>

G_BEGIN_DECLS

typedef struct _STCategory		STCategory;

/**
 * STCategoryURLCallback:
 * @category: the category which is about to be reloaded.
 *
 * Specifies the type of function to be stored in the
 * <structfield>url_cb</structfield> member of the #STCategory
 * structure. The function will be called before reloading @category,
 * and may update its <structfield>label</structfield> and
 * <structfield>url_postfix</structfield> members.
 *
 * Return value: the function should return %FALSE if the reload
 * should be cancelled.
 **/
typedef gboolean (*STCategoryURLCallback) (STCategory *category);

struct _STCategory
{
  char				*name;
  char				*label;
  char				*url_postfix;
  STCategoryURLCallback		url_cb;
};

STCategory	*st_category_new	(void);
void		st_category_free	(STCategory *category);

G_END_DECLS

#endif /* _ST_CATEGORY_API_H */
